package service

import (
	"context"
	"gokratos-base/api/service/demo"
	"gokratos-base/app/service/demo/internal/biz"
	"gokratos-base/app/service/demo/internal/model"
)

// DemoService is a demo service.
type DemoService struct {
	demo.UnimplementedDemoServer
	uc *biz.DemoUseCase
}

var _ demo.DemoServer = &DemoService{}

// NewDemoService new a demo service.
func NewDemoService(uc *biz.DemoUseCase) *DemoService {
	return &DemoService{uc: uc}
}

// Hello implements DemoServer.
func (s *DemoService) Hello(ctx context.Context, req *demo.HelloReq) (*demo.HelloRep, error) {
	return &demo.HelloRep{Message: "Hello " + req.Name}, nil
}
func (s *DemoService) Create(ctx context.Context, req *demo.CreateReq) (*demo.OKRep, error) {
	err := s.uc.CreateDemo(ctx, &model.Demo{Name: req.Name, Value: req.Value})
	if err != nil {
		return nil, err
	}
	return nil, nil
}

func (s *DemoService) Update(ctx context.Context, req *demo.UpdateReq) (*demo.OKRep, error) {
	err := s.uc.UpdateDemo(ctx, &model.Demo{Id: int(req.Id), Name: req.Name, Value: req.Value})
	if err != nil {
		return nil, err
	}
	return &demo.OKRep{}, nil

}

func (s *DemoService) Get(ctx context.Context, req *demo.IdReq) (*demo.DemoModel, error) {
	res, err := s.uc.GetDemo(ctx, int(req.Id))
	if err != nil {
		return nil, err
	}
	return DemoModelToRep(res), nil
}

func (s *DemoService) List(ctx context.Context, req *demo.ListReq) (*demo.ListRep, error) {
	list, err := s.uc.ListDemo(ctx, &biz.ListReq{
		Page: int(req.Page),
		Size: int(req.Size),
	})

	if err != nil {
		return nil, err
	}

	rep := &demo.ListRep{}
	rep.List = make([]*demo.DemoModel, 0, len(list))

	for _, v := range list {
		rep.List = append(rep.List, DemoModelToRep(v))
	}
	return rep, nil
}

func (s *DemoService) Delete(ctx context.Context, req *demo.IdReq) (*demo.OKRep, error) {
	err := s.uc.DeleteDemo(ctx, int(req.Id))
	if err != nil {
		return nil, err
	}
	return &demo.OKRep{}, nil
}
